<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="eu" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Honi buruz</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategoria:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Hasi torrenta</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Jauzi hash egiaztapena</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Sortu azpiagiritegia</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Torrent Kudeaketa Modua:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Guztiak</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Kategoriagabea</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Gehitu kategoria...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Kendu kategoria</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Kendu erabiligabeko kategoriak</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Berrekin torrentak</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Pausatu torrentak</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Ezabatu torrentak</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Kategoria Berria</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Editatu kategoria...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Irten qBittorrent-etik</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Lotura bakar bat lerroko</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Igoera neurri muga 0 baino handiagoa edo ezgaituta izan behar da.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Jeisketa neurri muga 0 baino handiagoa edo ezgaituta izan behar da.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Aukerazko igoera neurri muga 0 baino handiagoa edo ezgaituta izan behar da.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Aukerazko jeisketa neurri muga 0 baino handiagoa edo ezgaituta izan behar da.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Gehienezko jeisketa eraginda -1 baino handiagoa izan behar da.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Gehienezko igoera eraginda -1 baino handiagoa izan behar da.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Gehienezko torrent eraginda -1 baino handiagoa izan behar da.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Gehienezko elkarketa zenbateko muga 0 baino handiagoa edo ezgaituta izan behar da.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Gehienezko elkarketa zenbatekoa torrent bakoitzeko muga 0 baino handiagoa edo ezgaituta izan behar da.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Gehienezko igoera aho zenbatekoa torrent bakoitzeko muga 0 baino handiagoa edo ezgaituta izan behar da.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Ezinezkoa programa hobespenak gordetzea, qBittorrent zihurrenik erdietsiezina da.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent Freenode-an</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ezezaguna</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Elkarbanatze maila muga 0 eta 9998 artekoa izan behar da.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Emaritza denbora muga 0 eta 525600 minutu artekoa izan behar da.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Barrurako elkarketetarako erabilitzeko ataka 1 eta 65535 artekoa izan behar da.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Web EI-ak erabiltzeko ataka 1024 eta 65535 artekoa izan behar da.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Ezinezkoa saioa hastea, qBittorrent zihurrenik eskuraezina dago.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Erabiltzaile-izen edo Sarhitz baliogabea.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Erabiltzaile-izena</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Sarhitza</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Hasi Saioa</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Jatorrizko egileak</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Ezarri</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Gehitu</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Igo Torrentak</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Gorde agiriak kokaleku honetan:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookiea:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Idatzi agiritegia hemen</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Argibide gehiago</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Egiaztagiriei buruzko argibideak</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Ezarri kokalekua</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Mugatu igoera neurria</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Mugatu jeisketa neurria</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Berrizendatu torrenta</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Besterik...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Astelehena</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Asteartea</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Asteazkena</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Osteguna</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Ostirala</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Larunbata</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Igandea</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Amaitu saioa</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Jeitsi Torrentak beren URL edo Magnet loturatik</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Igo tokiko torrenta</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Zihur zaude hautaturiko torrentak ezabatzea nahi dituzula eskualdaketa zerrendatik?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gorde</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>qBittorrent bezeroa erdietsiezina da</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Igoera slot kopuru orokorraren muga 0 baino handiagoa edo ezgaituta izan behar da.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Kategoria izen baliogabea:\nMesedez ez erabili hizki berezirik kategoriaren izenean.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Ezinezkoa kategoria sortzea</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Igoera neurri muga 0 baino handiagoa izan behar da..</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editatu</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Toki askea: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Torrentaren jardungabe denboragailua 0 baino handiagoa izan behar da</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Gordetze Kudeaketa</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>Igoera neurri muga 0 baino handiagoa izan behar da.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent itzali egin da</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Editatu</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Tresnak</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Agiria</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Laguntza</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ikusi</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Aukerak...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Berrekin</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Lehentasun Gutxiena</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Lehentasun Gehiena</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Gutxitu Lehentasuna</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Handitu Lehentasuna</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Goiko Tresnabarra</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Egoera Barra</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Abiadura Izenaren Barran</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Eman Dirulaguntza!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Berrekin Denak</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estatistikak</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Honi buruz</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausatu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ezabatu</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Pasatu Denak</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Gehitu Torrent Agiria...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Agiritza</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Gehitu Torrent Lotura...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Bai</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ez</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Igoera Abiadura Muga Orokorra</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Jeisketa Abiadura Muga Orokorra</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Zihur zaude qBittorrent uztea nahi duzula?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[J: %1, I: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Aukerazko abiadura mugak</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Bilaketa Gailua</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Iragazi torrent zerrenda...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Bilaketa</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Eskualdaketak</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Aukerak</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Jeitsierak</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Elkarketa</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Abiadura</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Web EI</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Hizkuntza</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Erabiltzaile Interfaze Hizkuntza:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Post@ jakinarazpena jeitsiera osatutakoan</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Ekin kanpoko programa torrenta osatutakoan</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP Iragazketa</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Egitarautu aukerazko neurri muga erabilpena</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrent Lerrokapena</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Emaritu torrentak beren emaritza denbora erdietsi arte</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Berezgaitasunez gehitu aztarnari hauek jeitsiera berriei:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Web Erabiltzaile Interfazea (Hurruneko agintea)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP helbidea:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Zerbitzari domeinuak:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Erabili HTTPS, HTTP-ren ordez</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Igaropen egiaztapena tokiko-hostalariko berezoentzat</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Igaropen egiaztapena IP azpisare zerrenda-zuriko berezoentzat</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Eguneratu nire domeinu dinamikoaren izena</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Gorde osatugabeko torrentak hemen:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Kopiatu .torrent agiriak hona:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Kopiatu amaitutako jeisketa .torrent agiriak hona:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Aurre-esleitu diska tokia agiri guztientzat</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Gehitu .!qB luzapena osatugabeko agiriei</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Berezgaitasunez gehitu torrentak hemendik:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP zerbitzaria:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Zerbitzari honek elkarketa segurua behar du (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Egiaztapena</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Erabiltzaile-izena:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Sarhitza:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Gaitutako protokoloa:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP eta μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Aditze Ataka</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Barrurako elkarketentzako ataka:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Erabili UPnP / NAT-PMP ataka nire bideratzailetik bidaltzeko</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Erabili ataka ezberdina abiarazte bakoitzean</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Elkarketa Mugak</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Gehienezko elkarketa zenbatekoa torrent bakoitzeko:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Gehienezko elkarketa zenbatekoa orotara:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Gehienezko igoera aho zenbatekoa torrent bakoitzeko:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Gehienezko Igoera aho orokor zenbatekoa:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Proxy Zerbitzaria</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Mota:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Bat ere ez)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Hostalaria:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Ataka:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Erabili proxya hartzaile elkarketetarako</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Ezgaitu proxiek sostengatzen ez dituzten elkarketak</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Erabili proxya torrententzat bakarrik</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Iragazki helburua (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Eskuzko IP helbide eragoztea...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Ezarri aztarnariei</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Neurri Muga Orokorrak</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Igoera:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Jeitsiera:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Aukerazko Neurri Mugak</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Hemendik:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Hona:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Noiz:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Egunero</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Lanegunak</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Asteburuak</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Neurri Muga Ezarpenak</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Ezarri neurri muga burugain garraioari</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Ezarri neurri muga µTP protokoloari</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Pribatutatasuna</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Gaitu DHT (zentralizatugabeko sarea) hartzaile gehiago bilatzeko</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Gaitu Hartzaile Aldaketa (PeX) hartzaile gehiago bilatzeko</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Gaitu Tokiko Hartzaile Aurkikuntza hartzaile gehiago bilatzeko</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Enkriptaketa modua:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Hobetsi enkriptaketa</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Enkriptaketa beharrezkoa</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Ezgaitu enkriptaketa</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Gaitu izengabeko modua</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Gehienezko jeitsiera eraginda:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Gehienezko igoera eraginda:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Gehienezko torrent eraginda:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Ez zenbatu torrent geldoak muga hauetan</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Elkarbanatze Maila Mugapena</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Emaritu torrentak beren maila erdietsi arte</translation>
    </message>
    <message>
        <source>then</source>
        <translation>orduan</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Pausatu</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Kendu</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Erabili UPnP / NAT-PMP ataka nire bideratzailetik bidaltzeko</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Egiaztagiria:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Giltza:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Izena eman</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Domeinu izena:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Sostengatutako parametroak (hizki xehe-larriak bereiziz)</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Torrentaren izena</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategoria</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation>%G: Etiketak (kakotxaz bananduta)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Eduki helburua (torrent anitzerako erro helburua bezala)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Erro helburua (lehen torrent azpizuzenbide helburua)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Gordetze helburua</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Agiri zenbatekoa</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Torrentaren neurria (byte)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Oraingo aztarnaria</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Info hasha</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Aholkua: Enkapsulatu parametroa adartxo artean idazkia zuriune batekin ebakia izatea saihesteko (adib., "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Web EI erabiltzaile-izenak gutxienez 3 hizkirriko luzera izan behar du.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Web EI sarhitzak gutxienez 6 hizkirriko luzera izan behar du.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutu</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Gaitu clickjacking babesa</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Gaitu Cross-Site Request Forgery (CSRF) babesa</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Ezabatu .torrent agiriak edonola</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Jeitsiera neurri mugapena:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Igoera neurri mugapena:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Aldatu oraingo sarhitza</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Berezgaitasunezkoa</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Erabili aukerazko Web EI</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Berezko Gordetze Helbura:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Web EI agiri kokaleku alternatiboa ezin da hutsik egon.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Ez hasi jeisketa berezgaitasunez</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Aldatu torrenta Eskuzko Modura</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Torrent Kategoria aldatzean:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Berkokatu eragindako torrentak</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Ezarri neurri muga LAN-eko hartzaileei</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 esanahi du mugagabe</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Berkokatu torrenta</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Berezko Gordetze Helburua aldatzean:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Gaitu Hostalari idazburu balioztapena</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Segurtasuna</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Berezko Gordetze Helburua aldatzen denean:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Sortu azpiagiritegia agiri ugari duten torrententzat</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundu</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Aldatu eragindako torrentak Eskuzko Modura</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Agirien kokalekua:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Eskuzkoa</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Torrentaren jardungabe denboragailua:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Berezko Torrent Kudeaketa Modua:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Torrent bat gehitzean</translation>
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP-a</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Ataka</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Ikurrak</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Elkarketa</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Bezeroa</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Garapena</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Jeisketa Abiadura</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Igoera Abiadura</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Jeitsita</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Igota</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Garrantzia</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Agiriak</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Herrialdea</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Arrunta</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Handia</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Gehiena</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Orokorra</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Aztarnariak</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Hartzaileak</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP Iturburuak</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Edukia</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Jeitsita:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Eskualdaketa</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Denbora Ekinean:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>UED:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Igota:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Emaleak:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Jeisketa Abiadura:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Igoera Abiadura:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Hartzaileak:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Jeisketa Muga:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Igoera Muga:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Alperrik:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Elkarketak:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Argibideak</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Aipamena:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Elkarbanatze Maila:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Berriragarpena:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Azken Ikusaldia Osorik:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Neurria Guztira:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Atalak:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Sortzailea:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Gehituta:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Osatuta:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Sortua:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrent Hasha:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Gordetze Helburua:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Inoiz ez</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (ditu %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 saio honetan)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 geh)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 guztira)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 bat.-best.)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Jeitsiera muga:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Igoera muga:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Monitorizatutako Agiritegia</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Ezeztatu Gordetze Kokalekua</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Monitorizatutako agiritegia</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Berezko gordetze kokalekua</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Estatistikak</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Erabiltzaile estatistikak</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Katxe estatistikak</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Irakurri katxe arrakastasuak:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Bataz-besteko denbora lerroan:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Elkartutako hartzaileak:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Elkarbanatze maila orotara:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Jeitsiera orotara:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Saio hondakina:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Igoera orotara:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Buffer neurria guztira:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Egintza estatistikak</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Lerrokatutako S/I lanak:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Idazketa katxe gainzama:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Irakurketa katxe gainzama:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Lerrokatutako neurria guztira:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 elkargune</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Denak (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Jeisten (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Emaritzan (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Osatuta (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Berrekinda (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Pausatuta (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Jardunean (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Jardungabe (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Akastuna (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Denak (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Jeisten (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Emaritzan (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Osatuta (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Pausatuta (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Berrekinda (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Jardunean (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Jardungabe (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Akastuna (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Izena</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Neurria</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Garapena</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Jeitsiera Lehentasuna</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Gelditzen da</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Eskuragarritasuna</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Izena</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Neurria</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Eginda</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Egoera</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Emaritzak</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Hartzaileak</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Jeisketa Abiadura</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Igoera Abiadura</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Maila</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>UED</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategoria</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etiketak</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Gehituta</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Osatuta</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Aztarnaria</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Jeisketa Muga</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Igoera Muga</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Jeitsita</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Igota</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Saio Jeisketa</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Saio Igoera</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Gelditzen da</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Denbora Ekinean</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Gordetze helburua</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Osatuta</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Maila Muga</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Azken Ikusaldia Osorik</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Azken Jarduera</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Neurria Guztira</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL-a</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Egoera</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Hartzaileak</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mezua</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Jeitsita</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>Aztarnari URL-a:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Eguneratzen...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Lanean</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Ezgaituta</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Harremandu gabe oraindik</translation>
    </message>
    <message>
        <source>#</source>
        <translation>Zbk.</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>E/G</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Emaritzak</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Lan gabe</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Kopiatu aztarnari URL-a</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Gehitu aztarnari berri bat...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Editatu aztarnari URL-a...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Aztarnari edizioa</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Izainak</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Kendu aztarnaria</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Aztarnari gehitze elkarrizketa</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Gehitzeko aztarnarien zerrenda (bat lerroko):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>duela %1</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Esleitzen</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausatuta</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Osatuta</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Mugitzen</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[B] Emaritzen</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Emaritzan</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Lerrokatuta</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Akastuna</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[B] Jeisten</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Metadatuak jeisten</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Egiaztapena</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Ez dauden Agiriak </translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Egiaztapenerako lerrokatuta</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Jeisten</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Berrekite datuak egiaztatzen</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Geldituta</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Egoera</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategoriak</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Torrent Jeisketa Abiadura Muga</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Torrent Igoera Abiadura Muga</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Berrizendatu</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Berrekin</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Behartu Berrekitea</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Pausatu</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Ezabatu</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Mugatu elkarbanatze maila...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Mugatu igoera neurria...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Mugatu jeisketa neurria...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Mugitu gora</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Mugitu behera</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Mugitu goren</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Mugitu beheren</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Ezarri kokalekua...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Kopiatu izena</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Kopiatu hasha</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Jeitsi lehen eta azken atalak lehenik</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Berezgaitasunezko Torrent Kudeaketa</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategoria</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Berria...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Berrezarri</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Lehentasuna</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Behartu berregiaztapena</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Kopiatu magnet lotura</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Gain emaritza modua</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Berrizendatu...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Jeitsi sekuentzialki</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Behartu Berregiaztapena</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Kategoria Berria</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Kokalekua</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Izen berria</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Ezarri kokalekua</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Behartu berriragarpena</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Editatu Kategoria</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Gordetze helburua</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Torrent Igoera/Jeisketa Maila Muga</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Erabili maila muga orokorra</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Ezarri elkarbanatze mugarik gabe</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Ezarri elkarbanatze muga honela</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>maila</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutu</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>BitTorrent bezero aurreratua C++-rekin programatua, Qt toolkit-ean eta libtorrent-rasterbar-en ohinarrituta.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Etxeko Orrialdea:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Eztabaidagunea:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Akats Aztarnaria:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Ezabatze baieztapena</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Ezabatu agiriak diska gogorrean ere</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Ezabapen baieztapena - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Jeitsi URL-tatik</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Jeitsi</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Gehitu Torrent Loturak</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1o %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1e %2o</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Ezezaguna</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Gordetze helburua hutsik dago</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Ezeztatu</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Plugin helburua:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL-a edo tokiko zuzenbidea</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Ezarri plugina</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ongi</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Emaritzak:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Plugin guztiak</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Neurria:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Gelditu</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Bilaketa</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Bilatu pluginak...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Kategoria guztiak</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Bilatu hemen:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Kopiatu azalpen orrialdearen URL-a</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Joan azalpen orrialdera</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Emaitzak (erakusten</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Jeitsi</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Iragazkia</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Torrentaren izena bakarrik</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Gaituak bakarrik</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>kanpo -&gt;</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Edonon</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Kendu</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Ezarri plugin berria</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Bilaketa gailu plugin berriak lortu ditzakezu hemen:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Itxi</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Ezarritako bilaketa pluginak:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Gaituta</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Kontuz: Zihurtatu zure herrialdeko kopia-eskubide legeak betetzen dituzula torrentak jeisterakoan bilaketa gailu hauen bidez.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Egiaztatu eguneraketak</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Bilatu pluginak</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Izena</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Neurria</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Izainak</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Bilaketa gailua</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Emaleak</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Izena</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url-a</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Gaituta</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Bertsioa</translation>
    </message>
</context>
</TS>